pub enum IAccountKeychainErrors {
Show 17 variants
UnauthorizedCaller(UnauthorizedCaller),
KeyAlreadyExists(KeyAlreadyExists),
KeyNotFound(KeyNotFound),
KeyExpired(KeyExpired),
SpendingLimitExceeded(SpendingLimitExceeded),
InvalidSpendingLimit(InvalidSpendingLimit),
InvalidSignatureType(InvalidSignatureType),
ZeroPublicKey(ZeroPublicKey),
ExpiryInPast(ExpiryInPast),
KeyAlreadyRevoked(KeyAlreadyRevoked),
SignatureTypeMismatch(SignatureTypeMismatch),
CallNotAllowed(CallNotAllowed),
InvalidCallScope(InvalidCallScope),
InvalidKeyId(InvalidKeyId),
InvalidKeyAuthorizationWitness(InvalidKeyAuthorizationWitness),
KeyAuthorizationWitnessAlreadyBurned(KeyAuthorizationWitnessAlreadyBurned),
LegacyAuthorizeKeySelectorChanged(LegacyAuthorizeKeySelectorChanged),
}Expand description
Container for all the IAccountKeychain custom errors.
Variants
KeyAlreadyExists(KeyAlreadyExists)
KeyNotFound(KeyNotFound)
KeyExpired(KeyExpired)
SpendingLimitExceeded(SpendingLimitExceeded)
InvalidSpendingLimit(InvalidSpendingLimit)
InvalidSignatureType(InvalidSignatureType)
ZeroPublicKey(ZeroPublicKey)
ExpiryInPast(ExpiryInPast)
KeyAlreadyRevoked(KeyAlreadyRevoked)
SignatureTypeMismatch(SignatureTypeMismatch)
CallNotAllowed(CallNotAllowed)
InvalidCallScope(InvalidCallScope)
InvalidKeyId(InvalidKeyId)
InvalidKeyAuthorizationWitness(InvalidKeyAuthorizationWitness)
KeyAuthorizationWitnessAlreadyBurned(KeyAuthorizationWitnessAlreadyBurned)
LegacyAuthorizeKeySelectorChanged(LegacyAuthorizeKeySelectorChanged)
Implementations
Sourceimpl IAccountKeychainErrors
impl IAccountKeychainErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IAccountKeychainErrors
impl IAccountKeychainErrors
Creates a UnauthorizedCaller error.
error UnauthorizedCaller()Sourcepub fn key_already_exists() -> Self
pub fn key_already_exists() -> Self
Creates a KeyAlreadyExists error.
error KeyAlreadyExists()Sourcepub fn key_not_found() -> Self
pub fn key_not_found() -> Self
Creates a KeyNotFound error.
error KeyNotFound()Sourcepub fn key_expired() -> Self
pub fn key_expired() -> Self
Creates a KeyExpired error.
error KeyExpired()Sourcepub fn spending_limit_exceeded() -> Self
pub fn spending_limit_exceeded() -> Self
Creates a SpendingLimitExceeded error.
error SpendingLimitExceeded()Sourcepub fn invalid_spending_limit() -> Self
pub fn invalid_spending_limit() -> Self
Creates a InvalidSpendingLimit error.
error InvalidSpendingLimit()Sourcepub fn invalid_signature_type() -> Self
pub fn invalid_signature_type() -> Self
Creates a InvalidSignatureType error.
error InvalidSignatureType()Sourcepub fn zero_public_key() -> Self
pub fn zero_public_key() -> Self
Creates a ZeroPublicKey error.
error ZeroPublicKey()Sourcepub fn expiry_in_past() -> Self
pub fn expiry_in_past() -> Self
Creates a ExpiryInPast error.
error ExpiryInPast()Sourcepub fn key_already_revoked() -> Self
pub fn key_already_revoked() -> Self
Creates a KeyAlreadyRevoked error.
error KeyAlreadyRevoked()Sourcepub fn signature_type_mismatch(expected: u8, actual: u8) -> Self
pub fn signature_type_mismatch(expected: u8, actual: u8) -> Self
Creates a SignatureTypeMismatch error.
error SignatureTypeMismatch(uint8,uint8)Sourcepub fn call_not_allowed() -> Self
pub fn call_not_allowed() -> Self
Creates a CallNotAllowed error.
error CallNotAllowed()Sourcepub fn invalid_call_scope() -> Self
pub fn invalid_call_scope() -> Self
Creates a InvalidCallScope error.
error InvalidCallScope()Sourcepub fn invalid_key_id() -> Self
pub fn invalid_key_id() -> Self
Creates a InvalidKeyId error.
error InvalidKeyId()Creates a InvalidKeyAuthorizationWitness error.
error InvalidKeyAuthorizationWitness()Creates a KeyAuthorizationWitnessAlreadyBurned error.
error KeyAuthorizationWitnessAlreadyBurned()Creates a LegacyAuthorizeKeySelectorChanged error.
error LegacyAuthorizeKeySelectorChanged(bytes4)Trait Implementations
Sourceimpl Clone for IAccountKeychainErrors
impl Clone for IAccountKeychainErrors
Sourcefn clone(&self) -> IAccountKeychainErrors
fn clone(&self) -> IAccountKeychainErrors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IAccountKeychainErrors
impl Debug for IAccountKeychainErrors
Sourceimpl<'de> Deserialize<'de> for IAccountKeychainErrors
impl<'de> Deserialize<'de> for IAccountKeychainErrors
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for IAccountKeychainErrors
Sourceimpl PartialEq for IAccountKeychainErrors
impl PartialEq for IAccountKeychainErrors
Sourcefn eq(&self, other: &IAccountKeychainErrors) -> bool
fn eq(&self, other: &IAccountKeychainErrors) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IAccountKeychainErrors
impl Serialize for IAccountKeychainErrors
Sourceimpl SolInterface for IAccountKeychainErrors
impl SolInterface for IAccountKeychainErrors
Sourceconst MIN_DATA_LENGTH: usize = 0usize
const MIN_DATA_LENGTH: usize = 0usize
Sourcefn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.Sourcefn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
self.Sourcefn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
self, with validation. Read moreSourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
self into the given buffer.fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
self.fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
self, with validation. Read moreimpl StructuralPartialEq for IAccountKeychainErrors