pub enum IAccountKeychainEvents {
KeyAuthorized(KeyAuthorized),
AdminKeyAuthorized(AdminKeyAuthorized),
KeyRevoked(KeyRevoked),
SpendingLimitUpdated(SpendingLimitUpdated),
AccessKeySpend(AccessKeySpend),
KeyAuthorizationWitness(KeyAuthorizationWitness),
KeyAuthorizationWitnessBurned(KeyAuthorizationWitnessBurned),
}Expand description
Container for all the IAccountKeychain events.
Variants
KeyAuthorized(KeyAuthorized)
AdminKeyAuthorized(AdminKeyAuthorized)
KeyRevoked(KeyRevoked)
SpendingLimitUpdated(SpendingLimitUpdated)
AccessKeySpend(AccessKeySpend)
KeyAuthorizationWitness(KeyAuthorizationWitness)
KeyAuthorizationWitnessBurned(KeyAuthorizationWitnessBurned)
Implementations
Sourceimpl IAccountKeychainEvents
impl IAccountKeychainEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IAccountKeychainEvents
impl IAccountKeychainEvents
Creates a KeyAuthorized event.
event KeyAuthorized(address,address,uint8,uint64)Creates a AdminKeyAuthorized event.
event AdminKeyAuthorized(address,address)Sourcepub fn key_revoked(account: Address, public_key: Address) -> Self
pub fn key_revoked(account: Address, public_key: Address) -> Self
Creates a KeyRevoked event.
event KeyRevoked(address,address)Sourcepub fn spending_limit_updated(
account: Address,
public_key: Address,
token: Address,
new_limit: U256,
) -> Self
pub fn spending_limit_updated( account: Address, public_key: Address, token: Address, new_limit: U256, ) -> Self
Creates a SpendingLimitUpdated event.
event SpendingLimitUpdated(address,address,address,uint256)Sourcepub fn access_key_spend(
account: Address,
public_key: Address,
token: Address,
amount: U256,
remaining_limit: U256,
) -> Self
pub fn access_key_spend( account: Address, public_key: Address, token: Address, amount: U256, remaining_limit: U256, ) -> Self
Creates a AccessKeySpend event.
event AccessKeySpend(address,address,address,uint256,uint256)Creates a KeyAuthorizationWitness event.
event KeyAuthorizationWitness(address,bytes32)Creates a KeyAuthorizationWitnessBurned event.
event KeyAuthorizationWitnessBurned(address,bytes32)Trait Implementations
Sourceimpl Clone for IAccountKeychainEvents
impl Clone for IAccountKeychainEvents
Sourcefn clone(&self) -> IAccountKeychainEvents
fn clone(&self) -> IAccountKeychainEvents
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IAccountKeychainEvents
impl Debug for IAccountKeychainEvents
Sourceimpl<'de> Deserialize<'de> for IAccountKeychainEvents
impl<'de> Deserialize<'de> for IAccountKeychainEvents
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for IAccountKeychainEvents
Sourceimpl IntoLogData for IAccountKeychainEvents
impl IntoLogData for IAccountKeychainEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl PartialEq for IAccountKeychainEvents
impl PartialEq for IAccountKeychainEvents
Sourcefn eq(&self, other: &IAccountKeychainEvents) -> bool
fn eq(&self, other: &IAccountKeychainEvents) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IAccountKeychainEvents
impl Serialize for IAccountKeychainEvents
Sourceimpl SolEventInterface for IAccountKeychainEvents
impl SolEventInterface for IAccountKeychainEvents
Sourcefn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for IAccountKeychainEvents