pub struct KeyAuthorized {
pub account: Address,
pub publicKey: Address,
pub signatureType: u8,
pub expiry: u64,
}Expand description
Emitted when a new key is authorized
Event with signature KeyAuthorized(address,address,uint8,uint64) and selector 0x7c46af0758d3eca5e8195833bff1e5153f6249fc0f2968a878fd28544315a03c.
event KeyAuthorized(address indexed account, address indexed publicKey, uint8 signatureType, uint64 expiry);Fields
account: AddresspublicKey: AddresssignatureType: u8expiry: u64Trait Implementations
Sourceimpl Clone for KeyAuthorized
impl Clone for KeyAuthorized
Sourcefn clone(&self) -> KeyAuthorized
fn clone(&self) -> KeyAuthorized
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeyAuthorized
impl Debug for KeyAuthorized
Sourceimpl<'de> Deserialize<'de> for KeyAuthorized
impl<'de> Deserialize<'de> for KeyAuthorized
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&KeyAuthorized> for LogData
impl From<&KeyAuthorized> for LogData
Sourcefn from(this: &KeyAuthorized) -> LogData
fn from(this: &KeyAuthorized) -> LogData
Converts to this type from the input type.
Sourceimpl IntoLogData for KeyAuthorized
impl IntoLogData for KeyAuthorized
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a [
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a [
LogData] object.Sourceimpl JsonAbiExt for KeyAuthorized
impl JsonAbiExt for KeyAuthorized
Sourceimpl PartialEq for KeyAuthorized
impl PartialEq for KeyAuthorized
Sourceimpl Serialize for KeyAuthorized
impl Serialize for KeyAuthorized
Sourceimpl SolEvent for KeyAuthorized
impl SolEvent for KeyAuthorized
Sourceconst SIGNATURE: &'static str = "KeyAuthorized(address,address,uint8,uint64)"
const SIGNATURE: &'static str = "KeyAuthorized(address,address,uint8,uint64)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Uint<8>, Uint<64>)
type DataTuple<'a> = (Uint<8>, Uint<64>)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<KeyAuthorized as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<KeyAuthorized as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The [
TokenSeq] type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>, Address, Address)
type TopicList = (FixedBytes<32>, Address, Address)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Convert decoded rust data to the event type. Read more
Sourcefn check_signature(
topics: &<Self::TopicList as SolType>::RustType,
) -> Result<()>
fn check_signature( topics: &<Self::TopicList as SolType>::RustType, ) -> Result<()>
Check that the event’s signature matches the given topics.
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
Encode the topics of this event into the given buffer. Read more
fn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
Convert decoded rust data to the event type. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
fn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
fn encode_data(&self) -> Vec<u8> ⓘ
fn encode_data(&self) -> Vec<u8> ⓘ
ABI-encode the dynamic data of this event.
fn encode_topics(&self) -> Vec<WordToken>
fn encode_topics(&self) -> Vec<WordToken>
Encode the topics of this event. Read more
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
fn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
Encode this event to a [
LogData].fn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Transform ca [
Log] containing this event into a [Log] containing
[LogData].fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
Decode the topics of this event from the given data.
fn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
fn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer, with validation. Read more
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
Decode the event from the given log info.
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
Decode the event from the given log info, with validation. Read more
fn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object.
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object with validation.
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
Decode the event from the given log object.
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
Decode the event from the given log object with validation.
impl Eq for KeyAuthorized
impl StructuralPartialEq for KeyAuthorized