pub struct SignatureTypeMismatch {
pub expected: u8,
pub actual: u8,
}Expand description
Custom error with signature SignatureTypeMismatch(uint8,uint8) and selector 0xce699eca.
error SignatureTypeMismatch(uint8 expected, uint8 actual);Fields
expected: u8actual: u8Trait Implementations
Sourceimpl Clone for SignatureTypeMismatch
impl Clone for SignatureTypeMismatch
Sourcefn clone(&self) -> SignatureTypeMismatch
fn clone(&self) -> SignatureTypeMismatch
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SignatureTypeMismatch
impl Debug for SignatureTypeMismatch
Sourceimpl<'de> Deserialize<'de> for SignatureTypeMismatch
impl<'de> Deserialize<'de> for SignatureTypeMismatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonAbiExt for SignatureTypeMismatch
impl JsonAbiExt for SignatureTypeMismatch
Sourceimpl PartialEq for SignatureTypeMismatch
impl PartialEq for SignatureTypeMismatch
Sourceimpl Serialize for SignatureTypeMismatch
impl Serialize for SignatureTypeMismatch
Sourceimpl SolError for SignatureTypeMismatch
impl SolError for SignatureTypeMismatch
Sourceconst SIGNATURE: &'static str = "SignatureTypeMismatch(uint8,uint8)"
const SIGNATURE: &'static str = "SignatureTypeMismatch(uint8,uint8)"
The error’s ABI signature.
Sourcetype Parameters<'a> = (Uint<8>, Uint<8>)
type Parameters<'a> = (Uint<8>, Uint<8>)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<SignatureTypeMismatch as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<SignatureTypeMismatch as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding [
TokenSeq] type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the error to the given buffer with its selector.
impl Eq for SignatureTypeMismatch
impl StructuralPartialEq for SignatureTypeMismatch