pub struct isKeyAuthorizationWitnessBurnedReturn {
pub _0: bool,
}Expand description
Returns whether a TIP-1053 key-authorization witness has been manually burned.
Container type for the return parameters of the isKeyAuthorizationWitnessBurned(address,bytes32) function.
Fields
_0: boolTrait Implementations
Sourceimpl Clone for isKeyAuthorizationWitnessBurnedReturn
impl Clone for isKeyAuthorizationWitnessBurnedReturn
Sourcefn clone(&self) -> isKeyAuthorizationWitnessBurnedReturn
fn clone(&self) -> isKeyAuthorizationWitnessBurnedReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for isKeyAuthorizationWitnessBurnedReturn
impl<'de> Deserialize<'de> for isKeyAuthorizationWitnessBurnedReturn
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for isKeyAuthorizationWitnessBurnedReturn
Sourceimpl PartialEq for isKeyAuthorizationWitnessBurnedReturn
impl PartialEq for isKeyAuthorizationWitnessBurnedReturn
Sourcefn eq(&self, other: &isKeyAuthorizationWitnessBurnedReturn) -> bool
fn eq(&self, other: &isKeyAuthorizationWitnessBurnedReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for isKeyAuthorizationWitnessBurnedReturn